@@ -1,6 +1,6 @@
 /*============================================================================
 *
-*   WCSLIB 4.1 - an implementation of the FITS WCS convention.
+*   WCSLIB 4.2 - an implementation of the FITS WCS convention.
 *   Copyright (C) 1995-2005, Mark Calabretta
 *
 *   WCSLIB is free software; you can redistribute it and/or modify it under
@@ -27,7 +27,7 @@
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
 *   http://www.atnf.csiro.au/~mcalabre/index.html
-*   $Id: tpih1.c,v 4.1 2005/08/22 07:39:28 cal103 Exp $
+*   $Id: tpih1.c,v 4.2 2005/09/23 03:09:34 cal103 Exp $
 *=============================================================================
 *
 *   tpih1 tests wcspih(), the WCS FITS parser for image headers, and wcsfix(),
@@ -43,7 +43,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#ifdef DO_CFITSIO
+#if defined HAVE_CFITSIO && defined DO_CFITSIO
    #include <fitsio.h>
 #endif
 
@@ -59,7 +59,7 @@ int main()
    int  alts[27], ctrl, i, j, ncards, nreject, nwcs, relax, stat[NWCSFIX],
         status;
    struct wcsprm *wcs;
-#ifdef DO_CFITSIO
+#if defined HAVE_CFITSIO && defined DO_CFITSIO
    char *header;
    fitsfile *fptr;
 #else
@@ -68,11 +68,11 @@ int main()
    FILE *fptr;
 #endif
 
-   printf("\nTesting WCSLIB parser for FITS image headers\n"
-          "--------------------------------------------\n\n");
-
+   printf("Testing WCSLIB parser for FITS image headers (tpih1.c)\n"
+          "------------------------------------------------------\n\n");
+#if defined HAVE_CFITSIO && defined DO_CFITSIO
    /* Read in the FITS header discarding COMMENT, &c. cards in the process. */
-#ifdef DO_CFITSIO
+
    status = 0;
 
    if (fits_open_file(&fptr, infile, READONLY, &status)) {
@@ -129,6 +129,7 @@ int main()
    if (status = wcspih(header, ncards, relax, ctrl, &nreject, &nwcs, &wcs)) {
       fprintf(stderr, "wcspih ERROR %d: %s.\n", status, wcs_errmsg[status]);
    }
+   if (!nreject) fprintf(stderr, "(none)\n");
 
    /* List cards that were not consumed by wcspih(). */
    printf("\n\nNon-WCS header cards not used by wcspih():\n");
@@ -137,7 +138,7 @@ int main()
       printf("%.80s\n", hptr);
       hptr += 80;
    }
-#ifdef DO_CFITSIO
+#if defined HAVE_CFITSIO && defined DO_CFITSIO
    free(header);
 #endif
 
