@@ -1,6 +1,6 @@
 *=======================================================================
 *
-*   WCSLIB 4.1 - an implementation of the FITS WCS convention.
+*   WCSLIB 4.2 - an implementation of the FITS WCS convention.
 *   Copyright (C) 1995-2005, Mark Calabretta
 *
 *   WCSLIB is free software; you can redistribute it and/or modify it under
@@ -27,7 +27,7 @@
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
 *   http://www.atnf.csiro.au/~mcalabre/index.html
-*   $Id: tsph.f,v 4.1 2005/08/26 13:52:17 cal103 Exp $
+*   $Id: tsph.f,v 4.2 2005/09/21 13:37:53 cal103 Exp $
 *=======================================================================
 
       PROGRAM TSPH
@@ -47,17 +47,11 @@
       PARAMETER (PI = 3.141592653589793238462643D0)
       PARAMETER (D2R = PI/180D0)
 *-----------------------------------------------------------------------
-*     Uncomment the following two lines to raise SIGFPE on floating
-*     point exceptions for the Sun FORTRAN compiler.  This signal can
-*     be caught within 'dbx' by issuing the command "catch FPE".
-*#include <f77_floatingpoint.h>
-*      call ieee_handler ('set', 'common', SIGFPE_ABORT)
-
       WRITE (*, 5)
- 5    FORMAT (/,'Testing closure of WCSLIB coordinate transformation ',
-     :          'routines',/,
-     :          '----------------------------------------------------',
-     :          '--------')
+ 5    FORMAT ('Testing closure of WCSLIB coordinate transformation ',
+     :        'routines (tsph.f)',/,
+     :        '----------------------------------------------------',
+     :        '-----------------')
 
 *     Set reference angles.
       EUL(1) =  90D0
